Learn R Programming

mmiCATs (version 0.2.0)

append_KenRCATs: Append KenRCATs Results with Input Parameters

Description

Append KenRCATs Results with Input Parameters

Usage

append_KenRCATs(df, input)

Value

A list containing two data frames: the original results and the results with appended input parameters.

Arguments

df

A data frame containing simulation results.

input

A list of input parameters from the Shiny app.