cluster_im_lmRob: Cluster-Adjusted Confidence Intervals And p-Values Robust Linear Models
Description
Performs cluster-adjusted inference on a robust linear model object, using
robust linear regression within each cluster. This function is designed to
handle models where observations are clustered, and standard errors need to be
adjusted to account for this clustering. The function applies a robust linear
regression model to each cluster and then aggregates the results.