This function fits a linear model using robust estimation methods. It allows the use of either the 'robust' or 'robustbase' packages for fitting the model.
fit_model(engine, formula, data, ...)A fitted model.
A character string specifying the engine to be used for model fitting. Must be either "robust" or "robustbase".
An object of class formula (or one that can be coerced to that class): a symbolic description of the model to be fitted.
A dataframe
Additional arguments to be passed to the underlying fitting function.