This function fits a generalized linear model using robust estimation methods. It allows the use of either the 'robust' or 'robustbase' packages for fitting the model.
fit_model_g(engine, formula, data, family, method, ...)A fitted model
A character string specifying the engine to be used for model fitting. Must be either "robust" or "robustbase".
An object of class formula (or one that can be coerced to that class): a symbolic description of the model to be fitted.
A dataframe containing the variables in the model.
A description of the error distribution and link function to be used in the model (See stats::family for details of family functions).
Fitting method to be used. Can vary depending on the selected engine.
Additional arguments to be passed to the underlying fitting function.